read_rollout

Function read_rollout 

pub fn read_rollout(path: &Path) -> Result<RolloutContents, String>
Read a rollout tolerantly (ADR-0024 2.4 rules 1-2): unknown record types and unknown payload fields are skipped/ignored; an unparsable line (the torn tail) is skipped; a compacted record replaces all prior messages with its replacement_history.

Errors

Only when the file is unreadable or line 1 is not a valid session_meta (without a header the file identifies nothing).